==> apache-shardingsphere-5.5.1-src.zip: apache-shardingsphere-5.5.1-src-release/parser/sql/statement/core/src/test/java/org/apache/shardingsphere/sql/parser/statement/core/enums/LogicalOperatorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.sql.parser.statement.core.enums;

import org.junit.jupiter.api.Test;

import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertTrue;

class LogicalOperatorTest {
    
    @Test
    void assertValueFromAndText() {
        assertTrue(LogicalOperator.valueFrom("AND").isPresent());
        assertThat(LogicalOperator.valueFrom("AND").get(), is(LogicalOperator.AND));
        assertTrue(LogicalOperator.valueFrom("and").isPresent());
        assertThat(LogicalOperator.valueFrom("and").get(), is(LogicalOperator.AND));
    }
    
    @Test
    void assertValueFromAndSymbol() {
        assertTrue(LogicalOperator.valueFrom("&&").isPresent());
        assertThat(LogicalOperator.valueFrom("&&").get(), is(LogicalOperator.AND));
    }
    
    @Test
    void assertValueFromOrText() {
        assertTrue(LogicalOperator.valueFrom("OR").isPresent());
        assertThat(LogicalOperator.valueFrom("OR").get(), is(LogicalOperator.OR));
        assertTrue(LogicalOperator.valueFrom("or").isPresent());
        assertThat(LogicalOperator.valueFrom("or").get(), is(LogicalOperator.OR));
    }
    
    @Test
    void assertValueFromOrSymbol() {
        assertTrue(LogicalOperator.valueFrom("||").isPresent());
        assertThat(LogicalOperator.valueFrom("||").get(), is(LogicalOperator.OR));
    }
    
    @Test
    void assertValueFromInvalidValue() {
        assertFalse(LogicalOperator.valueFrom("XX").isPresent());
    }
}

==> apache-shardingsphere-5.5.2-src.zip: apache-shardingsphere-5.5.2-src-release/parser/sql/statement/core/src/test/java/org/apache/shardingsphere/sql/parser/statement/core/enums/LogicalOperatorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.sql.parser.statement.core.enums;

import org.junit.jupiter.api.Test;

import java.util.Optional;

import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.junit.jupiter.api.Assertions.assertFalse;

class LogicalOperatorTest {
    
    @Test
    void assertValueFromAndText() {
        assertThat(LogicalOperator.valueFrom("AND"), is(Optional.of(LogicalOperator.AND)));
        assertThat(LogicalOperator.valueFrom("and"), is(Optional.of(LogicalOperator.AND)));
    }
    
    @Test
    void assertValueFromAndSymbol() {
        assertThat(LogicalOperator.valueFrom("&&"), is(Optional.of(LogicalOperator.AND)));
    }
    
    @Test
    void assertValueFromOrText() {
        assertThat(LogicalOperator.valueFrom("OR"), is(Optional.of(LogicalOperator.OR)));
        assertThat(LogicalOperator.valueFrom("or"), is(Optional.of(LogicalOperator.OR)));
    }
    
    @Test
    void assertValueFromOrSymbol() {
        assertThat(LogicalOperator.valueFrom("||"), is(Optional.of(LogicalOperator.OR)));
    }
    
    @Test
    void assertValueFromInvalidValue() {
        assertFalse(LogicalOperator.valueFrom("XX").isPresent());
    }
}
